/* @copyright Itential, LLC 2019 (pre-modifications) */

// Set globals
/* global describe it log pronghornProps */
/* eslint no-unused-vars: warn */

// include required items for testing & logging
const assert = require('assert');
const fs = require('fs');
const mocha = require('mocha');
const path = require('path');
const winston = require('winston');
const { expect } = require('chai');
const { use } = require('chai');
const td = require('testdouble');

const anything = td.matchers.anything();

// stub and attemptTimeout are used throughout the code so set them here
let logLevel = 'none';
const stub = true;
const isRapidFail = false;
const isSaveMockData = false;
const attemptTimeout = 5000;

// these variables can be changed to run in integrated mode so easier to set them here
// always check these in with bogus data!!!
const host = 'replace.hostorip.here';
const username = 'username';
const password = 'password';
const protocol = 'http';
const port = 80;
const sslenable = false;
const sslinvalid = false;

// these are the adapter properties. You generally should not need to alter
// any of these after they are initially set up
global.pronghornProps = {
  pathProps: {
    encrypted: false
  },
  adapterProps: {
    adapters: [{
      id: 'Test-GitHub',
      type: 'GitHub',
      properties: {
        host,
        port,
        base_path: '/api',
        version: 'vv3',
        cache_location: 'none',
        encode_pathvars: true,
        save_metric: false,
        protocol,
        stub,
        authentication: {
          auth_method: 'no_authentication',
          username,
          password,
          token: '',
          token_timeout: -1,
          token_cache: 'local',
          invalid_token_error: 401,
          auth_field: 'header.headers.Authorization',
          auth_field_format: 'Basic {b64}{username}:{password}{/b64}',
          auth_logging: false
        },
        healthcheck: {
          type: 'none',
          frequency: 60000,
          query_object: {}
        },
        throttle: {
          throttle_enabled: false,
          number_pronghorns: 1,
          sync_async: 'sync',
          max_in_queue: 1000,
          concurrent_max: 1,
          expire_timeout: 0,
          avg_runtime: 200,
          priorities: [
            {
              value: 0,
              percent: 100
            }
          ]
        },
        request: {
          number_redirects: 0,
          number_retries: 3,
          limit_retry_error: 0,
          failover_codes: [],
          attempt_timeout: attemptTimeout,
          global_request: {
            payload: {},
            uriOptions: {},
            addlHeaders: {
              'user-agent': 'node.js'
            },
            authData: {}
          },
          healthcheck_on_timeout: true,
          return_raw: true,
          archiving: false,
          return_request: false
        },
        proxy: {
          enabled: false,
          host: '',
          port: 1,
          protocol: 'http',
          username: '',
          password: ''
        },
        ssl: {
          ecdhCurve: '',
          enabled: sslenable,
          accept_invalid_cert: sslinvalid,
          ca_file: '',
          key_file: '',
          cert_file: '',
          secure_protocol: '',
          ciphers: ''
        },
        mongo: {
          host: '',
          port: 0,
          database: '',
          username,
          password: '',
          replSet: '',
          db_ssl: {
            enabled: false,
            accept_invalid_cert: false,
            ca_file: '',
            key_file: '',
            cert_file: ''
          }
        }
      }
    }]
  }
};

global.$HOME = `${__dirname}/../..`;

// set the log levels that Pronghorn uses, spam and trace are not defaulted in so without
// this you may error on log.trace calls.
const myCustomLevels = {
  levels: {
    spam: 6,
    trace: 5,
    debug: 4,
    info: 3,
    warn: 2,
    error: 1,
    none: 0
  }
};

// need to see if there is a log level passed in
process.argv.forEach((val) => {
  // is there a log level defined to be passed in?
  if (val.indexOf('--LOG') === 0) {
    // get the desired log level
    const inputVal = val.split('=')[1];

    // validate the log level is supported, if so set it
    if (Object.hasOwnProperty.call(myCustomLevels.levels, inputVal)) {
      logLevel = inputVal;
    }
  }
});

// need to set global logging
global.log = winston.createLogger({
  level: logLevel,
  levels: myCustomLevels.levels,
  transports: [
    new winston.transports.Console()
  ]
});

/**
 * Runs the common asserts for test
 */
function runCommonAsserts(data, error) {
  assert.equal(undefined, error);
  assert.notEqual(undefined, data);
  assert.notEqual(null, data);
  assert.notEqual(undefined, data.response);
  assert.notEqual(null, data.response);
}

/**
 * Runs the error asserts for the test
 */
function runErrorAsserts(data, error, code, origin, displayStr) {
  assert.equal(null, data);
  assert.notEqual(undefined, error);
  assert.notEqual(null, error);
  assert.notEqual(undefined, error.IAPerror);
  assert.notEqual(null, error.IAPerror);
  assert.notEqual(undefined, error.IAPerror.displayString);
  assert.notEqual(null, error.IAPerror.displayString);
  assert.equal(code, error.icode);
  assert.equal(origin, error.IAPerror.origin);
  assert.equal(displayStr, error.IAPerror.displayString);
}

/**
 * @function saveMockData
 * Attempts to take data from responses and place them in MockDataFiles to help create Mockdata.
 * Note, this was built based on entity file structure for Adapter-Engine 1.6.x
 * @param {string} entityName - Name of the entity saving mock data for
 * @param {string} actionName -  Name of the action saving mock data for
 * @param {string} descriptor -  Something to describe this test (used as a type)
 * @param {string or object} responseData - The data to put in the mock file.
 */
function saveMockData(entityName, actionName, descriptor, responseData) {
  // do not need to save mockdata if we are running in stub mode (already has mock data) or if told not to save
  if (stub || !isSaveMockData) {
    return false;
  }

  // must have a response in order to store the response
  if (responseData && responseData.response) {
    let data = responseData.response;

    // if there was a raw response that one is better as it is untranslated
    if (responseData.raw) {
      data = responseData.raw;

      try {
        const temp = JSON.parse(data);
        data = temp;
      } catch (pex) {
        // do not care if it did not parse as we will just use data
      }
    }

    try {
      const base = path.join(__dirname, `../../entities/${entityName}/`);
      const mockdatafolder = 'mockdatafiles';
      const filename = `mockdatafiles/${actionName}-${descriptor}.json`;

      if (!fs.existsSync(base + mockdatafolder)) {
        fs.mkdirSync(base + mockdatafolder);
      }

      // write the data we retrieved
      fs.writeFile(base + filename, JSON.stringify(data, null, 2), 'utf8', (errWritingMock) => {
        if (errWritingMock) throw errWritingMock;

        // update the action file to reflect the changes. Note: We're replacing the default object for now!
        fs.readFile(`${base}action.json`, (errRead, content) => {
          if (errRead) throw errRead;

          // parse the action file into JSON
          const parsedJson = JSON.parse(content);

          // The object update we'll write in.
          const responseObj = {
            type: descriptor,
            key: '',
            mockFile: filename
          };

          // get the object for method we're trying to change.
          const currentMethodAction = parsedJson.actions.find((obj) => obj.name === actionName);

          // if the method was not found - should never happen but...
          if (!currentMethodAction) {
            throw Error('Can\'t find an action for this method in the provided entity.');
          }

          // if there is a response object, we want to replace the Response object. Otherwise we'll create one.
          const actionResponseObj = currentMethodAction.responseObjects.find((obj) => obj.type === descriptor);

          // Add the action responseObj back into the array of response objects.
          if (!actionResponseObj) {
            // if there is a default response object, we want to get the key.
            const defaultResponseObj = currentMethodAction.responseObjects.find((obj) => obj.type === 'default');

            // save the default key into the new response object
            if (defaultResponseObj) {
              responseObj.key = defaultResponseObj.key;
            }

            // save the new response object
            currentMethodAction.responseObjects = [responseObj];
          } else {
            // update the location of the mock data file
            actionResponseObj.mockFile = responseObj.mockFile;
          }

          // Save results
          fs.writeFile(`${base}action.json`, JSON.stringify(parsedJson, null, 2), (err) => {
            if (err) throw err;
          });
        });
      });
    } catch (e) {
      log.debug(`Failed to save mock data for ${actionName}. ${e.message}`);
      return false;
    }
  }

  // no response to save
  log.debug(`No data passed to save into mockdata for ${actionName}`);
  return false;
}

// require the adapter that we are going to be using
const GitHub = require('../../adapter.js');

// begin the testing - these should be pretty well defined between the describe and the it!
describe('[integration] GitHub Adapter Test', () => {
  describe('GitHub Class Tests', () => {
    const a = new GitHub(
      pronghornProps.adapterProps.adapters[0].id,
      pronghornProps.adapterProps.adapters[0].properties
    );

    if (isRapidFail) {
      const state = {};
      state.passed = true;

      mocha.afterEach(function x() {
        state.passed = state.passed
        && (this.currentTest.state === 'passed');
      });
      mocha.beforeEach(function x() {
        if (!state.passed) {
          return this.currentTest.skip();
        }
        return true;
      });
    }

    describe('#class instance created', () => {
      it('should be a class with properties', (done) => {
        try {
          assert.notEqual(null, a);
          assert.notEqual(undefined, a);
          assert.notEqual(null, a.allProps);
          const check = global.pronghornProps.adapterProps.adapters[0].properties.healthcheck.type;
          assert.equal(check, a.healthcheckType);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#connect', () => {
      it('should get connected - no healthcheck', (done) => {
        try {
          a.healthcheckType = 'none';
          a.connect();

          try {
            assert.equal(true, a.alive);
            done();
          } catch (error) {
            log.error(`Test Failure: ${error}`);
            done(error);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      });
      it('should get connected - startup healthcheck', (done) => {
        try {
          a.healthcheckType = 'startup';
          a.connect();

          try {
            assert.equal(true, a.alive);
            done();
          } catch (error) {
            log.error(`Test Failure: ${error}`);
            done(error);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      });
    });

    describe('#healthCheck', () => {
      it('should be healthy', (done) => {
        try {
          a.healthCheck(null, (data) => {
            try {
              assert.equal(true, a.healthy);
              saveMockData('system', 'healthcheck', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    /*
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    *** All code above this comment will be replaced during a migration ***
    ******************* DO NOT REMOVE THIS COMMENT BLOCK ******************
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    */

    describe('#getEmojis - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getEmojis((data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Emojis', 'getEmojis', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getEvents - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getEvents((data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Events', 'getEvents', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getFeeds - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getFeeds((data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.current_user_actor_url);
                assert.equal('string', data.response.current_user_organization_url);
                assert.equal('string', data.response.current_user_public);
                assert.equal('string', data.response.current_user_url);
                assert.equal('string', data.response.timeline_url);
                assert.equal('string', data.response.user_url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Feeds', 'getFeeds', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let gistsId = 'fakedata';
    const gistsPostGistsBodyParam = {
      description: 'string',
      files: {
        'file1.txt': {
          content: 'string'
        }
      },
      public: true
    };
    describe('#postGists - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postGists(gistsPostGistsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(10, data.response.comments);
                assert.equal('string', data.response.comments_url);
                assert.equal('string', data.response.created_at);
                assert.equal('string', data.response.description);
                assert.equal('object', typeof data.response.files);
                assert.equal(true, Array.isArray(data.response.forks));
                assert.equal('string', data.response.git_pull_url);
                assert.equal('string', data.response.git_push_url);
                assert.equal(true, Array.isArray(data.response.history));
                assert.equal('string', data.response.html_url);
                assert.equal('string', data.response.id);
                assert.equal(false, data.response.public);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              gistsId = data.response.id;
              saveMockData('Gists', 'postGists', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const gistsPostGistsIdCommentsBodyParam = {
      body: 'string'
    };
    describe('#postGistsIdComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postGistsIdComments(gistsId, gistsPostGistsIdCommentsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'postGistsIdComments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postGistsIdForks - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postGistsIdForks(gistsId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'postGistsIdForks', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGists - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getGists(null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'getGists', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsPublic - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getGistsPublic(null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'getGistsPublic', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsStarred - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getGistsStarred(null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'getGistsStarred', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const gistsPatchGistsIdBodyParam = {
      description: 'string',
      files: {
        'delete_this_file.txt': 'string',
        'file1.txt': {
          content: 'string'
        },
        'new_file.txt': {
          content: 'string'
        },
        'old_name.txt': {
          content: 'string',
          filename: 'string'
        }
      }
    };
    describe('#patchGistsId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchGistsId(gistsId, gistsPatchGistsIdBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(8, data.response.comments);
                assert.equal('string', data.response.comments_url);
                assert.equal('string', data.response.created_at);
                assert.equal('string', data.response.description);
                assert.equal('object', typeof data.response.files);
                assert.equal(true, Array.isArray(data.response.forks));
                assert.equal('string', data.response.git_pull_url);
                assert.equal('string', data.response.git_push_url);
                assert.equal(true, Array.isArray(data.response.history));
                assert.equal('string', data.response.html_url);
                assert.equal('string', data.response.id);
                assert.equal(false, data.response.public);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'patchGistsId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getGistsId(gistsId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(9, data.response.comments);
                assert.equal('string', data.response.comments_url);
                assert.equal('string', data.response.created_at);
                assert.equal('string', data.response.description);
                assert.equal('object', typeof data.response.files);
                assert.equal(true, Array.isArray(data.response.forks));
                assert.equal('string', data.response.git_pull_url);
                assert.equal('string', data.response.git_push_url);
                assert.equal(true, Array.isArray(data.response.history));
                assert.equal('string', data.response.html_url);
                assert.equal('string', data.response.id);
                assert.equal(false, data.response.public);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'getGistsId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsIdComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getGistsIdComments(gistsId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'getGistsIdComments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const gistsCommentId = 555;
    const gistsPatchGistsIdCommentsCommentIdBodyParam = {
      body: 'string'
    };
    describe('#patchGistsIdCommentsCommentId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchGistsIdCommentsCommentId(gistsId, gistsCommentId, gistsPatchGistsIdCommentsCommentIdBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'patchGistsIdCommentsCommentId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsIdCommentsCommentId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getGistsIdCommentsCommentId(gistsId, gistsCommentId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'getGistsIdCommentsCommentId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putGistsIdStar - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.putGistsIdStar(gistsId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'putGistsIdStar', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsIdStar - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getGistsIdStar(gistsId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'getGistsIdStar', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGitignoreTemplates - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getGitignoreTemplates((data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gitignore', 'getGitignoreTemplates', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const gitignoreLanguage = 'fakedata';
    describe('#getGitignoreTemplatesLanguage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getGitignoreTemplatesLanguage(gitignoreLanguage, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.source);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gitignore', 'getGitignoreTemplatesLanguage', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const issuesFilter = 'fakedata';
    const issuesState = 'fakedata';
    const issuesLabels = 'fakedata';
    const issuesSort = 'fakedata';
    const issuesDirection = 'fakedata';
    describe('#getIssues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getIssues(issuesFilter, issuesState, issuesLabels, issuesSort, issuesDirection, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Issues', 'getIssues', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const legacyKeyword = 'fakedata';
    const legacyState = 'fakedata';
    const legacyOwner = 'fakedata';
    const legacyRepository = 'fakedata';
    describe('#getLegacyIssuesSearchOwnerRepositoryStateKeyword - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getLegacyIssuesSearchOwnerRepositoryStateKeyword(legacyKeyword, legacyState, legacyOwner, legacyRepository, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(true, Array.isArray(data.response.issues));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Legacy', 'getLegacyIssuesSearchOwnerRepositoryStateKeyword', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getLegacyReposSearchKeyword - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getLegacyReposSearchKeyword(legacyKeyword, null, null, null, null, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Legacy', 'getLegacyReposSearchKeyword', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const legacyEmail = 'fakedata';
    describe('#getLegacyUserEmailEmail - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getLegacyUserEmailEmail(legacyEmail, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Legacy', 'getLegacyUserEmailEmail', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getLegacyUserSearchKeyword - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getLegacyUserSearchKeyword(legacyKeyword, null, null, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(true, Array.isArray(data.response.users));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Legacy', 'getLegacyUserSearchKeyword', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const markdownPostMarkdownBodyParam = {
      context: 'string',
      mode: 'string',
      text: 'string'
    };
    describe('#postMarkdown - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postMarkdown(markdownPostMarkdownBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Markdown', 'postMarkdown', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postMarkdownRaw - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postMarkdownRaw((data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Markdown', 'postMarkdownRaw', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getMeta - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getMeta((data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(true, Array.isArray(data.response.git));
                assert.equal(true, Array.isArray(data.response.hooks));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Meta', 'getMeta', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const networksOwner = 'fakedata';
    const networksRepo = 'fakedata';
    describe('#getNetworksOwnerRepoEvents - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getNetworksOwnerRepoEvents(networksOwner, networksRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Networks', 'getNetworksOwnerRepoEvents', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const notificationsPutNotificationsBodyParam = {
      last_read_at: 'string'
    };
    describe('#putNotifications - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.putNotifications(notificationsPutNotificationsBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Notifications', 'putNotifications', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let notificationsId = 'fakedata';
    describe('#getNotifications - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getNotifications(null, null, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(6, data.response.id);
                assert.equal('string', data.response.last_read_at);
                assert.equal('string', data.response.reason);
                assert.equal('object', typeof data.response.repository);
                assert.equal('object', typeof data.response.subject);
                assert.equal(false, data.response.unread);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              notificationsId = data.response.id;
              saveMockData('Notifications', 'getNotifications', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchNotificationsThreadsId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.patchNotificationsThreadsId(notificationsId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Notifications', 'patchNotificationsThreadsId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getNotificationsThreadsId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getNotificationsThreadsId(notificationsId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(4, data.response.id);
                assert.equal('string', data.response.last_read_at);
                assert.equal('string', data.response.reason);
                assert.equal('object', typeof data.response.repository);
                assert.equal('object', typeof data.response.subject);
                assert.equal(true, data.response.unread);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Notifications', 'getNotificationsThreadsId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const notificationsPutNotificationsThreadsIdSubscriptionBodyParam = {
      created_at: 'string',
      ignored: false,
      reason: {},
      subscribed: true,
      thread_url: 'string',
      url: 'string'
    };
    describe('#putNotificationsThreadsIdSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.putNotificationsThreadsIdSubscription(notificationsId, notificationsPutNotificationsThreadsIdSubscriptionBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.created_at);
                assert.equal(false, data.response.ignored);
                assert.equal('string', data.response.reason);
                assert.equal('string', data.response.repository_url);
                assert.equal(false, data.response.subscribed);
                assert.equal('string', data.response.thread_url);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Notifications', 'putNotificationsThreadsIdSubscription', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getNotificationsThreadsIdSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getNotificationsThreadsIdSubscription(notificationsId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.created_at);
                assert.equal(true, data.response.ignored);
                assert.equal('string', data.response.reason);
                assert.equal('string', data.response.repository_url);
                assert.equal(true, data.response.subscribed);
                assert.equal('string', data.response.thread_url);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Notifications', 'getNotificationsThreadsIdSubscription', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const orgsOrg = 'fakedata';
    const orgsPostOrgsOrgReposBodyParam = {
      name: 'string'
    };
    describe('#postOrgsOrgRepos - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postOrgsOrgRepos(orgsOrg, orgsPostOrgsOrgReposBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'postOrgsOrgRepos', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const orgsPostOrgsOrgTeamsBodyParam = {
      name: 'string'
    };
    describe('#postOrgsOrgTeams - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postOrgsOrgTeams(orgsOrg, orgsPostOrgsOrgTeamsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(6, data.response.id);
                assert.equal(8, data.response.members_count);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.permission);
                assert.equal(10, data.response.repos_count);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'postOrgsOrgTeams', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const orgsPatchOrgsOrgBodyParam = {
      billing_email: 'string',
      company: 'string',
      email: 'string',
      location: 'string',
      name: 'string'
    };
    describe('#patchOrgsOrg - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchOrgsOrg(orgsOrg, orgsPatchOrgsOrgBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.avatar_url);
                assert.equal('string', data.response.bio);
                assert.equal('string', data.response.blog);
                assert.equal(10, data.response.collaborators);
                assert.equal('string', data.response.company);
                assert.equal('string', data.response.created_at);
                assert.equal(5, data.response.disk_usage);
                assert.equal('string', data.response.email);
                assert.equal(9, data.response.followers);
                assert.equal('string', data.response.followers_url);
                assert.equal(2, data.response.following);
                assert.equal('string', data.response.following_url);
                assert.equal('string', data.response.gists_url);
                assert.equal('string', data.response.gravatar_id);
                assert.equal(false, data.response.hireable);
                assert.equal('string', data.response.html_url);
                assert.equal(2, data.response.id);
                assert.equal('string', data.response.location);
                assert.equal('string', data.response.login);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.organizations_url);
                assert.equal(4, data.response.owned_private_repos);
                assert.equal('object', typeof data.response.plan);
                assert.equal(9, data.response.private_gists);
                assert.equal(7, data.response.public_gists);
                assert.equal(10, data.response.public_repos);
                assert.equal('string', data.response.starred_url);
                assert.equal('string', data.response.subscriptions_url);
                assert.equal(10, data.response.total_private_repos);
                assert.equal('Organization', data.response.type);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'patchOrgsOrg', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrg - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getOrgsOrg(orgsOrg, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.avatar_url);
                assert.equal('string', data.response.bio);
                assert.equal('string', data.response.blog);
                assert.equal(1, data.response.collaborators);
                assert.equal('string', data.response.company);
                assert.equal('string', data.response.created_at);
                assert.equal(10, data.response.disk_usage);
                assert.equal('string', data.response.email);
                assert.equal(5, data.response.followers);
                assert.equal('string', data.response.followers_url);
                assert.equal(4, data.response.following);
                assert.equal('string', data.response.following_url);
                assert.equal('string', data.response.gists_url);
                assert.equal('string', data.response.gravatar_id);
                assert.equal(false, data.response.hireable);
                assert.equal('string', data.response.html_url);
                assert.equal(3, data.response.id);
                assert.equal('string', data.response.location);
                assert.equal('string', data.response.login);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.organizations_url);
                assert.equal(5, data.response.owned_private_repos);
                assert.equal('object', typeof data.response.plan);
                assert.equal(7, data.response.private_gists);
                assert.equal(7, data.response.public_gists);
                assert.equal(10, data.response.public_repos);
                assert.equal('string', data.response.starred_url);
                assert.equal('string', data.response.subscriptions_url);
                assert.equal(8, data.response.total_private_repos);
                assert.equal('User', data.response.type);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'getOrgsOrg', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgEvents - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getOrgsOrgEvents(orgsOrg, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'getOrgsOrgEvents', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const orgsFilter = 'fakedata';
    const orgsState = 'fakedata';
    const orgsLabels = 'fakedata';
    const orgsSort = 'fakedata';
    const orgsDirection = 'fakedata';
    describe('#getOrgsOrgIssues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getOrgsOrgIssues(orgsOrg, orgsFilter, orgsState, orgsLabels, orgsSort, orgsDirection, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'getOrgsOrgIssues', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgMembers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getOrgsOrgMembers(orgsOrg, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'getOrgsOrgMembers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const orgsUsername = 'fakedata';
    describe('#getOrgsOrgMembersUsername - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getOrgsOrgMembersUsername(orgsOrg, orgsUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'getOrgsOrgMembersUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgPublicMembers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getOrgsOrgPublicMembers(orgsOrg, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'getOrgsOrgPublicMembers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putOrgsOrgPublicMembersUsername - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.putOrgsOrgPublicMembersUsername(orgsOrg, orgsUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'putOrgsOrgPublicMembersUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgPublicMembersUsername - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getOrgsOrgPublicMembersUsername(orgsOrg, orgsUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'getOrgsOrgPublicMembersUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgRepos - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getOrgsOrgRepos(orgsOrg, null, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'getOrgsOrgRepos', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgTeams - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getOrgsOrgTeams(orgsOrg, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'getOrgsOrgTeams', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRateLimit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRateLimit((data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.rate);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('RateLimit', 'getRateLimit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposOwner = 'fakedata';
    const reposRepo = 'fakedata';
    let reposUser = 'fakedata';
    const reposShaCode = 'fakedata';
    let reposPathParam = 'fakedata';
    let reposId = 'fakedata';
    const reposPostReposOwnerRepoCommitsShaCodeCommentsBodyParam = {
      body: 'string',
      sha: 'string'
    };
    describe('#postReposOwnerRepoCommitsShaCodeComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoCommitsShaCodeComments(reposOwner, reposRepo, reposShaCode, reposPostReposOwnerRepoCommitsShaCodeCommentsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.commit_id);
                assert.equal('string', data.response.created_at);
                assert.equal('string', data.response.html_url);
                assert.equal(9, data.response.id);
                assert.equal(2, data.response.line);
                assert.equal('string', data.response.pathParam);
                assert.equal(8, data.response.position);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              reposUser = data.response.user;
              reposPathParam = data.response.pathParam;
              reposId = data.response.id;
              saveMockData('Repos', 'postReposOwnerRepoCommitsShaCodeComments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoDeploymentsBodyParam = {
      description: 'string',
      payload: {
        deploy_user: 'string',
        environment: 'string',
        room_id: 4
      },
      ref: 'string'
    };
    describe('#postReposOwnerRepoDeployments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoDeployments(reposOwner, reposRepo, reposPostReposOwnerRepoDeploymentsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.created_at);
                assert.equal('object', typeof data.response.creator);
                assert.equal('string', data.response.description);
                assert.equal(2, data.response.id);
                assert.equal('string', data.response.payload);
                assert.equal('string', data.response.sha);
                assert.equal('string', data.response.statuses_url);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoDeployments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoDeploymentsIdStatusesBodyParam = {
      description: 'string',
      state: 'string',
      target_url: 'string'
    };
    describe('#postReposOwnerRepoDeploymentsIdStatuses - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postReposOwnerRepoDeploymentsIdStatuses(reposOwner, reposRepo, reposId, reposPostReposOwnerRepoDeploymentsIdStatusesBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoDeploymentsIdStatuses', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoForksBodyParam = {
      organization: 'string'
    };
    describe('#postReposOwnerRepoForks - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postReposOwnerRepoForks(reposOwner, reposRepo, reposPostReposOwnerRepoForksBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoForks', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoGitBlobsBodyParam = {
      content: 'string',
      encoding: 'utf-8',
      sha: 'string',
      size: 10
    };
    describe('#postReposOwnerRepoGitBlobs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoGitBlobs(reposOwner, reposRepo, reposPostReposOwnerRepoGitBlobsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.sha);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoGitBlobs', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoGitCommitsBodyParam = {
      message: 'string',
      parents: [
        'string'
      ],
      tree: 'string'
    };
    describe('#postReposOwnerRepoGitCommits - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoGitCommits(reposOwner, reposRepo, reposPostReposOwnerRepoGitCommitsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.author);
                assert.equal('string', data.response.message);
                assert.equal('string', data.response.parents);
                assert.equal('string', data.response.tree);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoGitCommits', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let reposRef = 'fakedata';
    const reposPostReposOwnerRepoGitRefsBodyParam = {
      ref: 'string',
      sha: 'string'
    };
    describe('#postReposOwnerRepoGitRefs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoGitRefs(reposOwner, reposRepo, reposPostReposOwnerRepoGitRefsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.object);
                assert.equal('string', data.response.ref);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              reposRef = data.response.ref;
              saveMockData('Repos', 'postReposOwnerRepoGitRefs', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoGitTagsBodyParam = {
      message: 'string',
      object: 'string',
      tag: 'string',
      tagger: {},
      type: 'blob'
    };
    describe('#postReposOwnerRepoGitTags - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoGitTags(reposOwner, reposRepo, reposPostReposOwnerRepoGitTagsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.message);
                assert.equal('object', typeof data.response.object);
                assert.equal('string', data.response.sha);
                assert.equal('string', data.response.tag);
                assert.equal('object', typeof data.response.tagger);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoGitTags', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoGitTreesBodyParam = {
      sha: 'string',
      tree: [
        {
          mode: '160000',
          path: 'string',
          sha: 'string',
          size: 9,
          type: 'commit',
          url: 'string'
        }
      ],
      url: 'string'
    };
    describe('#postReposOwnerRepoGitTrees - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoGitTrees(reposOwner, reposRepo, reposPostReposOwnerRepoGitTreesBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.base_tree);
                assert.equal('string', data.response.sha);
                assert.equal(true, Array.isArray(data.response.tree));
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoGitTrees', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoHooksBodyParam = {
      active: true,
      add_events: [
        'string'
      ]
    };
    describe('#postReposOwnerRepoHooks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoHooks(reposOwner, reposRepo, reposPostReposOwnerRepoHooksBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoHooks', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposHookId = 555;
    describe('#postReposOwnerRepoHooksHookIdTests - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postReposOwnerRepoHooksHookIdTests(reposOwner, reposRepo, reposHookId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoHooksHookIdTests', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let reposAssignee = 'fakedata';
    let reposLabels = 'fakedata';
    const reposPostReposOwnerRepoIssuesBodyParam = {
      assignee: 'string',
      body: 'string',
      labels: [
        'string'
      ],
      milestone: 5,
      title: 'string'
    };
    describe('#postReposOwnerRepoIssues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoIssues(reposOwner, reposRepo, reposPostReposOwnerRepoIssuesBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.assignee);
                assert.equal('string', data.response.body);
                assert.equal(true, Array.isArray(data.response.labels));
                assert.equal(9, data.response.milestone);
                assert.equal('string', data.response.title);
              } else {
                runCommonAsserts(data, error);
              }
              reposAssignee = data.response.assignee;
              reposLabels = data.response.labels;
              saveMockData('Repos', 'postReposOwnerRepoIssues', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposNumber = 555;
    const reposPostReposOwnerRepoIssuesNumberCommentsBodyParam = {
      body: 'string'
    };
    describe('#postReposOwnerRepoIssuesNumberComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberComments(reposOwner, reposRepo, reposNumber, reposPostReposOwnerRepoIssuesNumberCommentsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.created_at);
                assert.equal('string', data.response.html_url);
                assert.equal(1, data.response.id);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoIssuesNumberComments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let reposName = 'fakedata';
    const reposPostReposOwnerRepoIssuesNumberLabelsBodyParam = [
      'string'
    ];
    describe('#postReposOwnerRepoIssuesNumberLabels - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberLabels(reposOwner, reposRepo, reposNumber, reposPostReposOwnerRepoIssuesNumberLabelsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.color);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              reposName = data.response.name;
              saveMockData('Repos', 'postReposOwnerRepoIssuesNumberLabels', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let reposKeyId = 555;
    const reposPostReposOwnerRepoKeysBodyParam = {
      key: 'string',
      title: 'string'
    };
    describe('#postReposOwnerRepoKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoKeys(reposOwner, reposRepo, reposPostReposOwnerRepoKeysBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(10, data.response.id);
                assert.equal('string', data.response.key);
                assert.equal('string', data.response.title);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              reposKeyId = data.response.id;
              saveMockData('Repos', 'postReposOwnerRepoKeys', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoLabelsBodyParam = [
      'string'
    ];
    describe('#postReposOwnerRepoLabels - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoLabels(reposOwner, reposRepo, reposPostReposOwnerRepoLabelsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.color);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoLabels', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoMergesBodyParam = {
      base: 'string',
      commit_message: 'string',
      head: 'string'
    };
    describe('#postReposOwnerRepoMerges - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoMerges(reposOwner, reposRepo, reposPostReposOwnerRepoMergesBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.author);
                assert.equal('string', data.response.comments_url);
                assert.equal('object', typeof data.response.commit);
                assert.equal('object', typeof data.response.committer);
                assert.equal(false, data.response.merged);
                assert.equal('string', data.response.message);
                assert.equal(true, Array.isArray(data.response.parents));
                assert.equal('string', data.response.sha);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoMerges', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let reposState = 'fakedata';
    const reposPostReposOwnerRepoMilestonesBodyParam = {
      description: 'string',
      due_on: 'string',
      state: 'string',
      title: 'string'
    };
    describe('#postReposOwnerRepoMilestones - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoMilestones(reposOwner, reposRepo, reposPostReposOwnerRepoMilestonesBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(4, data.response.closed_issues);
                assert.equal('string', data.response.created_at);
                assert.equal('object', typeof data.response.creator);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.due_on);
                assert.equal(5, data.response.number);
                assert.equal(9, data.response.open_issues);
                assert.equal('closed', data.response.state);
                assert.equal('string', data.response.title);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              reposState = data.response.state;
              saveMockData('Repos', 'postReposOwnerRepoMilestones', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoPullsBodyParam = {
      base: 'string',
      body: 'string',
      head: 'string',
      title: 'string'
    };
    describe('#postReposOwnerRepoPulls - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postReposOwnerRepoPulls(reposOwner, reposRepo, reposPostReposOwnerRepoPullsBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoPulls', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoPullsNumberCommentsBodyParam = {
      body: 'string',
      commit_id: 'string',
      path: 'string',
      position: 3
    };
    describe('#postReposOwnerRepoPullsNumberComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoPullsNumberComments(reposOwner, reposRepo, reposNumber, reposPostReposOwnerRepoPullsNumberCommentsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.commit_id);
                assert.equal('string', data.response.created_at);
                assert.equal(5, data.response.id);
                assert.equal('string', data.response.pathParam);
                assert.equal(5, data.response.position);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoPullsNumberComments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoReleasesBodyParam = {
      body: 'string',
      draft: true,
      name: 'string',
      prerelease: false,
      tag_name: 'string',
      target_commitish: 'string'
    };
    describe('#postReposOwnerRepoReleases - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoReleases(reposOwner, reposRepo, reposPostReposOwnerRepoReleasesBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(true, Array.isArray(data.response.assets));
                assert.equal('string', data.response.assets_url);
                assert.equal('object', typeof data.response.author);
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.created_at);
                assert.equal(true, data.response.draft);
                assert.equal('string', data.response.html_url);
                assert.equal(9, data.response.id);
                assert.equal('string', data.response.name);
                assert.equal(true, data.response.prerelease);
                assert.equal('string', data.response.published_at);
                assert.equal('string', data.response.tag_name);
                assert.equal('string', data.response.tarball_url);
                assert.equal('string', data.response.target_commitish);
                assert.equal('string', data.response.upload_url);
                assert.equal('string', data.response.url);
                assert.equal('string', data.response.zipball_url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoReleases', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPostReposOwnerRepoStatusesRefBodyParam = {
      object: {
        sha: 'string',
        type: 'string',
        url: 'string'
      },
      ref: 'string',
      url: 'string'
    };
    describe('#postReposOwnerRepoStatusesRef - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postReposOwnerRepoStatusesRef(reposOwner, reposRepo, reposRef, reposPostReposOwnerRepoStatusesRefBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'postReposOwnerRepoStatusesRef', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPatchReposOwnerRepoBodyParam = {
      description: 'string',
      has_downloads: true,
      has_issues: true,
      has_wiki: false,
      homepage: 'string',
      name: 'string',
      private: false
    };
    describe('#patchReposOwnerRepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.patchReposOwnerRepo(reposOwner, reposRepo, reposPatchReposOwnerRepoBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'patchReposOwnerRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getReposOwnerRepo(reposOwner, reposRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoAssignees - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoAssignees(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoAssignees', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoAssigneesAssignee - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getReposOwnerRepoAssigneesAssignee(reposOwner, reposRepo, reposAssignee, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoAssigneesAssignee', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoBranches - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoBranches(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoBranches', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposBranch = 'fakedata';
    describe('#getReposOwnerRepoBranchesBranch - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoBranchesBranch(reposOwner, reposRepo, reposBranch, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.commit);
                assert.equal('string', data.response.name);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoBranchesBranch', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCollaborators - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoCollaborators(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoCollaborators', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoCollaboratorsUser - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.putReposOwnerRepoCollaboratorsUser(reposOwner, reposRepo, reposUser, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'putReposOwnerRepoCollaboratorsUser', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCollaboratorsUser - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getReposOwnerRepoCollaboratorsUser(reposOwner, reposRepo, reposUser, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoCollaboratorsUser', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoComments(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoComments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposCommentId = 555;
    const reposPatchReposOwnerRepoCommentsCommentIdBodyParam = {
      body: 'string'
    };
    describe('#patchReposOwnerRepoCommentsCommentId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchReposOwnerRepoCommentsCommentId(reposOwner, reposRepo, reposCommentId, reposPatchReposOwnerRepoCommentsCommentIdBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.commit_id);
                assert.equal('string', data.response.created_at);
                assert.equal('string', data.response.html_url);
                assert.equal(6, data.response.id);
                assert.equal(3, data.response.line);
                assert.equal('string', data.response.pathParam);
                assert.equal(3, data.response.position);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'patchReposOwnerRepoCommentsCommentId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommentsCommentId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoCommentsCommentId(reposOwner, reposRepo, reposCommentId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.commit_id);
                assert.equal('string', data.response.created_at);
                assert.equal('string', data.response.html_url);
                assert.equal(8, data.response.id);
                assert.equal(1, data.response.line);
                assert.equal('string', data.response.pathParam);
                assert.equal(7, data.response.position);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoCommentsCommentId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommits - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoCommits(reposOwner, reposRepo, null, null, reposPathParam, null, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoCommits', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommitsRefStatus - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoCommitsRefStatus(reposOwner, reposRepo, reposRef, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoCommitsRefStatus', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommitsShaCode - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCode(reposOwner, reposRepo, reposShaCode, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.author);
                assert.equal('object', typeof data.response.commit);
                assert.equal('object', typeof data.response.committer);
                assert.equal(true, Array.isArray(data.response.files));
                assert.equal(true, Array.isArray(data.response.parents));
                assert.equal('string', data.response.sha);
                assert.equal('object', typeof data.response.stats);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoCommitsShaCode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommitsShaCodeComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCodeComments(reposOwner, reposRepo, reposShaCode, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoCommitsShaCodeComments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposBaseId = 'fakedata';
    const reposHeadId = 'fakedata';
    describe('#getReposOwnerRepoCompareBaseIdHeadId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoCompareBaseIdHeadId(reposOwner, reposRepo, reposBaseId, reposHeadId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(2, data.response.ahead_by);
                assert.equal('object', typeof data.response.base_commit);
                assert.equal(8, data.response.behind_by);
                assert.equal(true, Array.isArray(data.response.commits));
                assert.equal('string', data.response.diff_url);
                assert.equal(true, Array.isArray(data.response.files));
                assert.equal('string', data.response.html_url);
                assert.equal('string', data.response.patch_url);
                assert.equal('string', data.response.permalink_url);
                assert.equal('string', data.response.status);
                assert.equal(10, data.response.total_commits);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoCompareBaseIdHeadId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPutReposOwnerRepoContentsPathBodyParam = {
      committer: {
        email: 'string',
        name: 'string'
      },
      content: 'string',
      message: 'string'
    };
    describe('#putReposOwnerRepoContentsPath - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.putReposOwnerRepoContentsPath(reposOwner, reposRepo, reposPathParam, reposPutReposOwnerRepoContentsPathBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.commit);
                assert.equal('string', typeof data.response.content);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'putReposOwnerRepoContentsPath', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoContentsPath - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoContentsPath(reposOwner, reposRepo, reposPathParam, null, reposRef, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('2Zb\u001e', data.response.content);
                assert.equal('string', data.response.encoding);
                assert.equal('string', data.response.git_url);
                assert.equal('string', data.response.html_url);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.pathParam);
                assert.equal('string', data.response.sha);
                assert.equal(6, data.response.size);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoContentsPath', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposAnon = 'fakedata';
    describe('#getReposOwnerRepoContributors - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoContributors(reposOwner, reposRepo, reposAnon, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoContributors', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDeployments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoDeployments(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoDeployments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDeploymentsIdStatuses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoDeploymentsIdStatuses(reposOwner, reposRepo, reposId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoDeploymentsIdStatuses', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDownloads - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoDownloads(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoDownloads', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposDownloadId = 555;
    describe('#getReposOwnerRepoDownloadsDownloadId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoDownloadsDownloadId(reposOwner, reposRepo, reposDownloadId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.content_type);
                assert.equal('string', data.response.description);
                assert.equal(8, data.response.download_count);
                assert.equal('string', data.response.html_url);
                assert.equal(9, data.response.id);
                assert.equal('string', data.response.name);
                assert.equal(9, data.response.size);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoDownloadsDownloadId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoEvents - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoEvents(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoEvents', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposSort = 'fakedata';
    describe('#getReposOwnerRepoForks - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getReposOwnerRepoForks(reposOwner, reposRepo, reposSort, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoForks', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitBlobsShaCode - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoGitBlobsShaCode(reposOwner, reposRepo, reposShaCode, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.content);
                assert.equal('base64', data.response.encoding);
                assert.equal('string', data.response.sha);
                assert.equal(6, data.response.size);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoGitBlobsShaCode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitCommitsShaCode - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoGitCommitsShaCode(reposOwner, reposRepo, reposShaCode, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.author);
                assert.equal('object', typeof data.response.committer);
                assert.equal('string', data.response.message);
                assert.equal(true, Array.isArray(data.response.parents));
                assert.equal('string', data.response.sha);
                assert.equal('object', typeof data.response.tree);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoGitCommitsShaCode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitRefs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoGitRefs(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoGitRefs', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitMatchingRefs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoGitMatchingRefs(reposOwner, reposRepo, 'fakedata', (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoGitMatchingRefs', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPatchReposOwnerRepoGitRefsRefBodyParam = {
      force: false,
      sha: 'string'
    };
    describe('#patchReposOwnerRepoGitRefsRef - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchReposOwnerRepoGitRefsRef(reposOwner, reposRepo, reposRef, reposPatchReposOwnerRepoGitRefsRefBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.object);
                assert.equal('string', data.response.ref);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'patchReposOwnerRepoGitRefsRef', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitRefsRef - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoGitRefsRef(reposOwner, reposRepo, reposRef, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.object);
                assert.equal('string', data.response.ref);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoGitRefsRef', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitTagsShaCode - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoGitTagsShaCode(reposOwner, reposRepo, reposShaCode, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.message);
                assert.equal('object', typeof data.response.object);
                assert.equal('string', data.response.sha);
                assert.equal('string', data.response.tag);
                assert.equal('object', typeof data.response.tagger);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoGitTagsShaCode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitTreesShaCode - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoGitTreesShaCode(reposOwner, reposRepo, reposShaCode, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.sha);
                assert.equal(true, Array.isArray(data.response.tree));
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoGitTreesShaCode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoHooks - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoHooks(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoHooks', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPatchReposOwnerRepoHooksHookIdBodyParam = {
      active: true,
      add_events: [
        'string'
      ]
    };
    describe('#patchReposOwnerRepoHooksHookId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchReposOwnerRepoHooksHookId(reposOwner, reposRepo, reposHookId, reposPatchReposOwnerRepoHooksHookIdBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'patchReposOwnerRepoHooksHookId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoHooksHookId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoHooksHookId(reposOwner, reposRepo, reposHookId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoHooksHookId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposFilter = 'fakedata';
    const reposDirection = 'fakedata';
    describe('#getReposOwnerRepoIssues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoIssues(reposOwner, reposRepo, reposFilter, reposState, reposLabels, reposSort, reposDirection, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoIssues', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoIssuesComments(reposOwner, reposRepo, reposDirection, reposSort, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoIssuesComments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPatchReposOwnerRepoIssuesCommentsCommentIdBodyParam = {
      body: 'string'
    };
    describe('#patchReposOwnerRepoIssuesCommentsCommentId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchReposOwnerRepoIssuesCommentsCommentId(reposOwner, reposRepo, reposCommentId, reposPatchReposOwnerRepoIssuesCommentsCommentIdBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.created_at);
                assert.equal('string', data.response.html_url);
                assert.equal(2, data.response.id);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'patchReposOwnerRepoIssuesCommentsCommentId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesCommentsCommentId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoIssuesCommentsCommentId(reposOwner, reposRepo, reposCommentId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.created_at);
                assert.equal('string', data.response.html_url);
                assert.equal(9, data.response.id);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoIssuesCommentsCommentId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesEvents - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoIssuesEvents(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoIssuesEvents', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposEventId = 555;
    describe('#getReposOwnerRepoIssuesEventsEventId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoIssuesEventsEventId(reposOwner, reposRepo, reposEventId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.actor);
                assert.equal('string', data.response.commit_id);
                assert.equal('string', data.response.created_at);
                assert.equal('string', data.response.event);
                assert.equal('object', typeof data.response.issue);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoIssuesEventsEventId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPatchReposOwnerRepoIssuesNumberBodyParam = {
      assignee: 'string',
      body: 'string',
      labels: [
        'string'
      ],
      milestone: 7,
      title: 'string'
    };
    describe('#patchReposOwnerRepoIssuesNumber - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchReposOwnerRepoIssuesNumber(reposOwner, reposRepo, reposNumber, reposPatchReposOwnerRepoIssuesNumberBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.assignee);
                assert.equal('string', data.response.body);
                assert.equal(true, Array.isArray(data.response.labels));
                assert.equal(4, data.response.milestone);
                assert.equal('string', data.response.title);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'patchReposOwnerRepoIssuesNumber', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumber - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumber(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.assignee);
                assert.equal('string', data.response.body);
                assert.equal(true, Array.isArray(data.response.labels));
                assert.equal(5, data.response.milestone);
                assert.equal('string', data.response.title);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoIssuesNumber', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumberComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberComments(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoIssuesNumberComments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumberEvents - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberEvents(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoIssuesNumberEvents', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPutReposOwnerRepoIssuesNumberLabelsBodyParam = [
      'string'
    ];
    describe('#putReposOwnerRepoIssuesNumberLabels - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.putReposOwnerRepoIssuesNumberLabels(reposOwner, reposRepo, reposNumber, reposPutReposOwnerRepoIssuesNumberLabelsBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.color);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'putReposOwnerRepoIssuesNumberLabels', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumberLabels - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberLabels(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoIssuesNumberLabels', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoKeys(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoKeys', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoKeysKeyId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoKeysKeyId(reposOwner, reposRepo, reposKeyId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(7, data.response.id);
                assert.equal('string', data.response.key);
                assert.equal('string', data.response.title);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoKeysKeyId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoLabels - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoLabels(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoLabels', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPatchReposOwnerRepoLabelsNameBodyParam = [
      'string'
    ];
    describe('#patchReposOwnerRepoLabelsName - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchReposOwnerRepoLabelsName(reposOwner, reposRepo, reposName, reposPatchReposOwnerRepoLabelsNameBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.color);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'patchReposOwnerRepoLabelsName', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoLabelsName - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoLabelsName(reposOwner, reposRepo, reposName, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.color);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoLabelsName', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoLanguages - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getReposOwnerRepoLanguages(reposOwner, reposRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoLanguages', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoMilestones - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoMilestones(reposOwner, reposRepo, reposState, reposDirection, reposSort, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(2, data.response.closed_issues);
                assert.equal('string', data.response.created_at);
                assert.equal('object', typeof data.response.creator);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.due_on);
                assert.equal(2, data.response.number);
                assert.equal(8, data.response.open_issues);
                assert.equal('open', data.response.state);
                assert.equal('string', data.response.title);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoMilestones', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPatchReposOwnerRepoMilestonesNumberBodyParam = {
      description: 'string',
      due_on: 'string',
      state: 'string',
      title: 'string'
    };
    describe('#patchReposOwnerRepoMilestonesNumber - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchReposOwnerRepoMilestonesNumber(reposOwner, reposRepo, reposNumber, reposPatchReposOwnerRepoMilestonesNumberBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(4, data.response.closed_issues);
                assert.equal('string', data.response.created_at);
                assert.equal('object', typeof data.response.creator);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.due_on);
                assert.equal(4, data.response.number);
                assert.equal(4, data.response.open_issues);
                assert.equal('closed', data.response.state);
                assert.equal('string', data.response.title);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'patchReposOwnerRepoMilestonesNumber', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoMilestonesNumber - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumber(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(2, data.response.closed_issues);
                assert.equal('string', data.response.created_at);
                assert.equal('object', typeof data.response.creator);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.due_on);
                assert.equal(2, data.response.number);
                assert.equal(1, data.response.open_issues);
                assert.equal('open', data.response.state);
                assert.equal('string', data.response.title);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoMilestonesNumber', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoMilestonesNumberLabels - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumberLabels(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoMilestonesNumberLabels', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPutReposOwnerRepoNotificationsBodyParam = {
      last_read_at: 'string'
    };
    describe('#putReposOwnerRepoNotifications - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.putReposOwnerRepoNotifications(reposOwner, reposRepo, reposPutReposOwnerRepoNotificationsBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'putReposOwnerRepoNotifications', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoNotifications - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoNotifications(reposOwner, reposRepo, null, null, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(10, data.response.id);
                assert.equal('string', data.response.last_read_at);
                assert.equal('string', data.response.reason);
                assert.equal('object', typeof data.response.repository);
                assert.equal('object', typeof data.response.subject);
                assert.equal(true, data.response.unread);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoNotifications', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPulls - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getReposOwnerRepoPulls(reposOwner, reposRepo, reposState, null, null, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoPulls', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoPullsComments(reposOwner, reposRepo, reposDirection, reposSort, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoPullsComments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPatchReposOwnerRepoPullsCommentsCommentIdBodyParam = {
      body: 'string'
    };
    describe('#patchReposOwnerRepoPullsCommentsCommentId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchReposOwnerRepoPullsCommentsCommentId(reposOwner, reposRepo, reposCommentId, reposPatchReposOwnerRepoPullsCommentsCommentIdBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.commit_id);
                assert.equal('string', data.response.created_at);
                assert.equal(4, data.response.id);
                assert.equal('string', data.response.pathParam);
                assert.equal(8, data.response.position);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'patchReposOwnerRepoPullsCommentsCommentId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsCommentsCommentId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoPullsCommentsCommentId(reposOwner, reposRepo, reposCommentId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.commit_id);
                assert.equal('string', data.response.created_at);
                assert.equal(6, data.response.id);
                assert.equal('string', data.response.pathParam);
                assert.equal(3, data.response.position);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoPullsCommentsCommentId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPatchReposOwnerRepoPullsNumberBodyParam = {
      body: 'string',
      state: 'string',
      title: 'string'
    };
    describe('#patchReposOwnerRepoPullsNumber - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.patchReposOwnerRepoPullsNumber(reposOwner, reposRepo, reposNumber, reposPatchReposOwnerRepoPullsNumberBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'patchReposOwnerRepoPullsNumber', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumber - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getReposOwnerRepoPullsNumber(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoPullsNumber', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberComments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberComments(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.commit_id);
                assert.equal('string', data.response.created_at);
                assert.equal(3, data.response.id);
                assert.equal('string', data.response.pathParam);
                assert.equal(7, data.response.position);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
                assert.equal('object', typeof data.response.user);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoPullsNumberComments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberCommits - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommits(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoPullsNumberCommits', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberFiles - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberFiles(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoPullsNumberFiles', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPutReposOwnerRepoPullsNumberMergeBodyParam = {
      commit_message: 'string'
    };
    describe('#putReposOwnerRepoPullsNumberMerge - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.putReposOwnerRepoPullsNumberMerge(reposOwner, reposRepo, reposNumber, reposPutReposOwnerRepoPullsNumberMergeBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(false, data.response.merged);
                assert.equal('string', data.response.message);
                assert.equal('string', data.response.sha);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'putReposOwnerRepoPullsNumberMerge', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberMerge - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberMerge(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoPullsNumberMerge', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReadme - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoReadme(reposOwner, reposRepo, reposRef, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.content);
                assert.equal('string', data.response.encoding);
                assert.equal('string', data.response.git_url);
                assert.equal('string', data.response.html_url);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.pathParam);
                assert.equal('string', data.response.sha);
                assert.equal(3, data.response.size);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoReadme', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleases - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoReleases(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoReleases', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPatchReposOwnerRepoReleasesAssetsIdBodyParam = {
      name: 'string'
    };
    describe('#patchReposOwnerRepoReleasesAssetsId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchReposOwnerRepoReleasesAssetsId(reposOwner, reposRepo, reposId, reposPatchReposOwnerRepoReleasesAssetsIdBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.content_type);
                assert.equal('string', data.response.created_at);
                assert.equal(7, data.response.download_count);
                assert.equal(6, data.response.id);
                assert.equal('string', data.response.label);
                assert.equal('string', data.response.name);
                assert.equal(9, data.response.size);
                assert.equal('string', data.response.state);
                assert.equal('string', data.response.updated_at);
                assert.equal('object', typeof data.response.uploader);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'patchReposOwnerRepoReleasesAssetsId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleasesAssetsId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoReleasesAssetsId(reposOwner, reposRepo, reposId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.content_type);
                assert.equal('string', data.response.created_at);
                assert.equal(9, data.response.download_count);
                assert.equal(4, data.response.id);
                assert.equal('string', data.response.label);
                assert.equal('string', data.response.name);
                assert.equal(3, data.response.size);
                assert.equal('string', data.response.state);
                assert.equal('string', data.response.updated_at);
                assert.equal('object', typeof data.response.uploader);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoReleasesAssetsId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPatchReposOwnerRepoReleasesIdBodyParam = {
      body: 'string',
      draft: false,
      name: 'string',
      prerelease: true,
      tag_name: 'string',
      target_commitish: 'string'
    };
    describe('#patchReposOwnerRepoReleasesId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchReposOwnerRepoReleasesId(reposOwner, reposRepo, reposId, reposPatchReposOwnerRepoReleasesIdBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(true, Array.isArray(data.response.assets));
                assert.equal('string', data.response.assets_url);
                assert.equal('object', typeof data.response.author);
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.created_at);
                assert.equal(true, data.response.draft);
                assert.equal('string', data.response.html_url);
                assert.equal(4, data.response.id);
                assert.equal('string', data.response.name);
                assert.equal(true, data.response.prerelease);
                assert.equal('string', data.response.published_at);
                assert.equal('string', data.response.tag_name);
                assert.equal('string', data.response.tarball_url);
                assert.equal('string', data.response.target_commitish);
                assert.equal('string', data.response.upload_url);
                assert.equal('string', data.response.url);
                assert.equal('string', data.response.zipball_url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'patchReposOwnerRepoReleasesId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleasesId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoReleasesId(reposOwner, reposRepo, reposId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(true, Array.isArray(data.response.assets));
                assert.equal('string', data.response.assets_url);
                assert.equal('object', typeof data.response.author);
                assert.equal('string', data.response.body);
                assert.equal('string', data.response.created_at);
                assert.equal(false, data.response.draft);
                assert.equal('string', data.response.html_url);
                assert.equal(6, data.response.id);
                assert.equal('string', data.response.name);
                assert.equal(true, data.response.prerelease);
                assert.equal('string', data.response.published_at);
                assert.equal('string', data.response.tag_name);
                assert.equal('string', data.response.tarball_url);
                assert.equal('string', data.response.target_commitish);
                assert.equal('string', data.response.upload_url);
                assert.equal('string', data.response.url);
                assert.equal('string', data.response.zipball_url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoReleasesId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleasesIdAssets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoReleasesIdAssets(reposOwner, reposRepo, reposId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoReleasesIdAssets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStargazers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoStargazers(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoStargazers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsCodeFrequency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoStatsCodeFrequency(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(4, data.response[0]);
                assert.equal(8, data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoStatsCodeFrequency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsCommitActivity - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoStatsCommitActivity(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoStatsCommitActivity', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsContributors - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoStatsContributors(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoStatsContributors', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsParticipation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoStatsParticipation(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(true, Array.isArray(data.response.all));
                assert.equal(true, Array.isArray(data.response.owner));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoStatsParticipation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsPunchCard - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoStatsPunchCard(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(10, data.response[0]);
                assert.equal(3, data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoStatsPunchCard', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatusesRef - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoStatusesRef(reposOwner, reposRepo, reposRef, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoStatusesRef', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoSubscribers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoSubscribers(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoSubscribers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposPutReposOwnerRepoSubscriptionBodyParam = {
      ignored: false,
      subscribed: true
    };
    describe('#putReposOwnerRepoSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.putReposOwnerRepoSubscription(reposOwner, reposRepo, reposPutReposOwnerRepoSubscriptionBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.created_at);
                assert.equal(true, data.response.ignored);
                assert.equal('string', data.response.reason);
                assert.equal('string', data.response.repository_url);
                assert.equal(true, data.response.subscribed);
                assert.equal('string', data.response.thread_url);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'putReposOwnerRepoSubscription', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoSubscription - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoSubscription(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.created_at);
                assert.equal(true, data.response.ignored);
                assert.equal('string', data.response.reason);
                assert.equal('string', data.response.repository_url);
                assert.equal(false, data.response.subscribed);
                assert.equal('string', data.response.thread_url);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoSubscription', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoTags - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoTags(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoTags', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoTeams - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoTeams(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoTeams', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoWatchers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getReposOwnerRepoWatchers(reposOwner, reposRepo, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoWatchers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposArchiveFormat = 'fakedata';
    describe('#getReposOwnerRepoArchiveFormatPath - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getReposOwnerRepoArchiveFormatPath(reposOwner, reposRepo, reposArchiveFormat, reposPathParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'getReposOwnerRepoArchiveFormatPath', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRepositories - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getRepositories(null, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repositories', 'getRepositories', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const searchQ = 'fakedata';
    describe('#getSearchCode - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getSearchCode(null, searchQ, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(true, Array.isArray(data.response.items));
                assert.equal(8, data.response.total_count);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Search', 'getSearchCode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchIssues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getSearchIssues(null, searchQ, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(true, Array.isArray(data.response.items));
                assert.equal(8, data.response.total_count);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Search', 'getSearchIssues', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchRepositories - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getSearchRepositories(null, searchQ, null, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Search', 'getSearchRepositories', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchUsers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getSearchUsers(null, searchQ, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(true, Array.isArray(data.response.items));
                assert.equal(7, data.response.total_count);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Search', 'getSearchUsers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const teamsTeamId = 555;
    const teamsPatchTeamsTeamIdBodyParam = {
      name: 'string'
    };
    describe('#patchTeamsTeamId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchTeamsTeamId(teamsTeamId, teamsPatchTeamsTeamIdBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(7, data.response.id);
                assert.equal(6, data.response.members_count);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.permission);
                assert.equal(2, data.response.repos_count);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'patchTeamsTeamId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getTeamsTeamId(teamsTeamId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(2, data.response.id);
                assert.equal(1, data.response.members_count);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.permission);
                assert.equal(7, data.response.repos_count);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'getTeamsTeamId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdMembers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getTeamsTeamIdMembers(teamsTeamId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'getTeamsTeamIdMembers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const teamsUsername = 'fakedata';
    describe('#putTeamsTeamIdMembersUsername - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.putTeamsTeamIdMembersUsername(teamsTeamId, teamsUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'putTeamsTeamIdMembersUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdMembersUsername - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getTeamsTeamIdMembersUsername(teamsTeamId, teamsUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'getTeamsTeamIdMembersUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putTeamsTeamIdMembershipsUsername - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.putTeamsTeamIdMembershipsUsername(teamsTeamId, teamsUsername, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.state);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'putTeamsTeamIdMembershipsUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdMembershipsUsername - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getTeamsTeamIdMembershipsUsername(teamsTeamId, teamsUsername, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.state);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'getTeamsTeamIdMembershipsUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdRepos - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getTeamsTeamIdRepos(teamsTeamId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'getTeamsTeamIdRepos', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const teamsOwner = 'fakedata';
    const teamsRepo = 'fakedata';
    describe('#putTeamsTeamIdReposOwnerRepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.putTeamsTeamIdReposOwnerRepo(teamsTeamId, teamsOwner, teamsRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'putTeamsTeamIdReposOwnerRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdReposOwnerRepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getTeamsTeamIdReposOwnerRepo(teamsTeamId, teamsOwner, teamsRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'getTeamsTeamIdReposOwnerRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const userPostUserEmailsBodyParam = [
      'string'
    ];
    describe('#postUserEmails - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postUserEmails(userPostUserEmailsBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'postUserEmails', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let userKeyId = 555;
    const userPostUserKeysBodyParam = {
      key: 'string',
      title: 'string'
    };
    describe('#postUserKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postUserKeys(userPostUserKeysBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(2, data.response.id);
                assert.equal('string', data.response.key);
                assert.equal('string', data.response.title);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              userKeyId = data.response.id;
              saveMockData('User', 'postUserKeys', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const userPostUserReposBodyParam = {
      name: 'string'
    };
    describe('#postUserRepos - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postUserRepos(userPostUserReposBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'postUserRepos', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const userPatchUserBodyParam = {
      bio: 'string',
      blog: 'string',
      company: 'string',
      email: 'string',
      hireable: true,
      location: 'string',
      name: 'string'
    };
    describe('#patchUser - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchUser(userPatchUserBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.avatar_url);
                assert.equal('string', data.response.bio);
                assert.equal('string', data.response.blog);
                assert.equal(2, data.response.collaborators);
                assert.equal('string', data.response.company);
                assert.equal('string', data.response.created_at);
                assert.equal(1, data.response.disk_usage);
                assert.equal('string', data.response.email);
                assert.equal(1, data.response.followers);
                assert.equal('string', data.response.followers_url);
                assert.equal(9, data.response.following);
                assert.equal('string', data.response.following_url);
                assert.equal('string', data.response.gists_url);
                assert.equal('string', data.response.gravatar_id);
                assert.equal(true, data.response.hireable);
                assert.equal('string', data.response.html_url);
                assert.equal(7, data.response.id);
                assert.equal('string', data.response.location);
                assert.equal('string', data.response.login);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.organizations_url);
                assert.equal(2, data.response.owned_private_repos);
                assert.equal('object', typeof data.response.plan);
                assert.equal(8, data.response.private_gists);
                assert.equal(3, data.response.public_gists);
                assert.equal(10, data.response.public_repos);
                assert.equal('string', data.response.starred_url);
                assert.equal('string', data.response.subscriptions_url);
                assert.equal(6, data.response.total_private_repos);
                assert.equal('Organization', data.response.type);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'patchUser', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUser - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUser((data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.avatar_url);
                assert.equal('string', data.response.bio);
                assert.equal('string', data.response.blog);
                assert.equal(1, data.response.collaborators);
                assert.equal('string', data.response.company);
                assert.equal('string', data.response.created_at);
                assert.equal(6, data.response.disk_usage);
                assert.equal('string', data.response.email);
                assert.equal(9, data.response.followers);
                assert.equal('string', data.response.followers_url);
                assert.equal(3, data.response.following);
                assert.equal('string', data.response.following_url);
                assert.equal('string', data.response.gists_url);
                assert.equal('string', data.response.gravatar_id);
                assert.equal(false, data.response.hireable);
                assert.equal('string', data.response.html_url);
                assert.equal(1, data.response.id);
                assert.equal('string', data.response.location);
                assert.equal('string', data.response.login);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.organizations_url);
                assert.equal(7, data.response.owned_private_repos);
                assert.equal('object', typeof data.response.plan);
                assert.equal(2, data.response.private_gists);
                assert.equal(7, data.response.public_gists);
                assert.equal(8, data.response.public_repos);
                assert.equal('string', data.response.starred_url);
                assert.equal('string', data.response.subscriptions_url);
                assert.equal(8, data.response.total_private_repos);
                assert.equal('Organization', data.response.type);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUser', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserEmails - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUserEmails((data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response[0]);
                assert.equal('string', data.response[1]);
                assert.equal('string', data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserEmails', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserFollowers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUserFollowers((data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserFollowers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserFollowing - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUserFollowing((data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserFollowing', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const userUsername = 'fakedata';
    describe('#putUserFollowingUsername - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.putUserFollowingUsername(userUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'putUserFollowingUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserFollowingUsername - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUserFollowingUsername(userUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserFollowingUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const userFilter = 'fakedata';
    const userState = 'fakedata';
    const userLabels = 'fakedata';
    const userSort = 'fakedata';
    const userDirection = 'fakedata';
    describe('#getUserIssues - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUserIssues(userFilter, userState, userLabels, userSort, userDirection, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserIssues', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUserKeys((data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserKeys', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserKeysKeyId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUserKeysKeyId(userKeyId, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal(10, data.response.id);
                assert.equal('string', data.response.key);
                assert.equal('string', data.response.title);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserKeysKeyId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserOrgs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUserOrgs((data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserOrgs', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserRepos - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUserRepos(null, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserRepos', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserStarred - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUserStarred(userDirection, userSort, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserStarred', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const userOwner = 'fakedata';
    const userRepo = 'fakedata';
    describe('#putUserStarredOwnerRepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.putUserStarredOwnerRepo(userOwner, userRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'putUserStarredOwnerRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserStarredOwnerRepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUserStarredOwnerRepo(userOwner, userRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserStarredOwnerRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserSubscriptions - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUserSubscriptions((data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserSubscriptions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putUserSubscriptionsOwnerRepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.putUserSubscriptionsOwnerRepo(userOwner, userRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'putUserSubscriptionsOwnerRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserSubscriptionsOwnerRepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUserSubscriptionsOwnerRepo(userOwner, userRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserSubscriptionsOwnerRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserTeams - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUserTeams((data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'getUserTeams', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUsers(null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const usersUsername = 'fakedata';
    describe('#getUsersUsername - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUsersUsername(usersUsername, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('string', data.response.avatar_url);
                assert.equal('string', data.response.bio);
                assert.equal('string', data.response.blog);
                assert.equal(5, data.response.collaborators);
                assert.equal('string', data.response.company);
                assert.equal('string', data.response.created_at);
                assert.equal(8, data.response.disk_usage);
                assert.equal('string', data.response.email);
                assert.equal(2, data.response.followers);
                assert.equal('string', data.response.followers_url);
                assert.equal(6, data.response.following);
                assert.equal('string', data.response.following_url);
                assert.equal('string', data.response.gists_url);
                assert.equal('string', data.response.gravatar_id);
                assert.equal(true, data.response.hireable);
                assert.equal('string', data.response.html_url);
                assert.equal(5, data.response.id);
                assert.equal('string', data.response.location);
                assert.equal('string', data.response.login);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.organizations_url);
                assert.equal(4, data.response.owned_private_repos);
                assert.equal('object', typeof data.response.plan);
                assert.equal(5, data.response.private_gists);
                assert.equal(8, data.response.public_gists);
                assert.equal(7, data.response.public_repos);
                assert.equal('string', data.response.starred_url);
                assert.equal('string', data.response.subscriptions_url);
                assert.equal(3, data.response.total_private_repos);
                assert.equal('Organization', data.response.type);
                assert.equal('string', data.response.updated_at);
                assert.equal('string', data.response.url);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameEvents - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUsersUsernameEvents(usersUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsernameEvents', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const usersOrg = 'fakedata';
    describe('#getUsersUsernameEventsOrgsOrg - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUsersUsernameEventsOrgsOrg(usersUsername, usersOrg, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsernameEventsOrgsOrg', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameFollowers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUsersUsernameFollowers(usersUsername, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsernameFollowers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const usersTargetUser = 'fakedata';
    describe('#getUsersUsernameFollowingTargetUser - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUsersUsernameFollowingTargetUser(usersUsername, usersTargetUser, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsernameFollowingTargetUser', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameGists - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUsersUsernameGists(usersUsername, null, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsernameGists', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameKeys - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUsersUsernameKeys(usersUsername, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsernameKeys', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameOrgs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getUsersUsernameOrgs(usersUsername, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsernameOrgs', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameReceivedEvents - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUsersUsernameReceivedEvents(usersUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsernameReceivedEvents', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameReceivedEventsPublic - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUsersUsernameReceivedEventsPublic(usersUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsernameReceivedEventsPublic', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameRepos - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUsersUsernameRepos(usersUsername, null, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsernameRepos', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameStarred - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUsersUsernameStarred(usersUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsernameStarred', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameSubscriptions - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getUsersUsernameSubscriptions(usersUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Users', 'getUsersUsernameSubscriptions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteGistsId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteGistsId(gistsId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'deleteGistsId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteGistsIdCommentsCommentId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteGistsIdCommentsCommentId(gistsId, gistsCommentId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'deleteGistsIdCommentsCommentId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteGistsIdStar - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteGistsIdStar(gistsId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Gists', 'deleteGistsIdStar', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteNotificationsThreadsIdSubscription - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteNotificationsThreadsIdSubscription(notificationsId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Notifications', 'deleteNotificationsThreadsIdSubscription', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteOrgsOrgMembersUsername - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteOrgsOrgMembersUsername(orgsOrg, orgsUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'deleteOrgsOrgMembersUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteOrgsOrgPublicMembersUsername - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteOrgsOrgPublicMembersUsername(orgsOrg, orgsUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Orgs', 'deleteOrgsOrgPublicMembersUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepo(reposOwner, reposRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoCollaboratorsUser - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoCollaboratorsUser(reposOwner, reposRepo, reposUser, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoCollaboratorsUser', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoCommentsCommentId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoCommentsCommentId(reposOwner, reposRepo, reposCommentId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoCommentsCommentId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const reposDeleteReposOwnerRepoContentsPathBodyParam = {
      committer: {
        email: 'string',
        name: 'string'
      },
      message: 'string',
      sha: 'string'
    };
    describe('#deleteReposOwnerRepoContentsPath - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.deleteReposOwnerRepoContentsPath(reposOwner, reposRepo, reposPathParam, reposDeleteReposOwnerRepoContentsPathBodyParam, (data, error) => {
            try {
              runCommonAsserts(data, error);
              if (stub) {
                assert.equal('object', typeof data.response.commit);
                assert.equal('string', data.response.content);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoContentsPath', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoDownloadsDownloadId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoDownloadsDownloadId(reposOwner, reposRepo, reposDownloadId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoDownloadsDownloadId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoGitRefsRef - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoGitRefsRef(reposOwner, reposRepo, reposRef, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoGitRefsRef', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoHooksHookId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoHooksHookId(reposOwner, reposRepo, reposHookId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoHooksHookId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoIssuesCommentsCommentId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesCommentsCommentId(reposOwner, reposRepo, reposCommentId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoIssuesCommentsCommentId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoIssuesNumberLabels - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabels(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoIssuesNumberLabels', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoIssuesNumberLabelsName - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabelsName(reposOwner, reposRepo, reposNumber, reposName, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoIssuesNumberLabelsName', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoKeysKeyId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoKeysKeyId(reposOwner, reposRepo, reposKeyId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoKeysKeyId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoLabelsName - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoLabelsName(reposOwner, reposRepo, reposName, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoLabelsName', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoMilestonesNumber - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoMilestonesNumber(reposOwner, reposRepo, reposNumber, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoMilestonesNumber', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoPullsCommentsCommentId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoPullsCommentsCommentId(reposOwner, reposRepo, reposCommentId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoPullsCommentsCommentId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoReleasesAssetsId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesAssetsId(reposOwner, reposRepo, reposId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoReleasesAssetsId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoReleasesId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesId(reposOwner, reposRepo, reposId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoReleasesId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoSubscription - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteReposOwnerRepoSubscription(reposOwner, reposRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Repos', 'deleteReposOwnerRepoSubscription', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteTeamsTeamId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteTeamsTeamId(teamsTeamId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'deleteTeamsTeamId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteTeamsTeamIdMembersUsername - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteTeamsTeamIdMembersUsername(teamsTeamId, teamsUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'deleteTeamsTeamIdMembersUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteTeamsTeamIdMembershipsUsername - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteTeamsTeamIdMembershipsUsername(teamsTeamId, teamsUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'deleteTeamsTeamIdMembershipsUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteTeamsTeamIdReposOwnerRepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteTeamsTeamIdReposOwnerRepo(teamsTeamId, teamsOwner, teamsRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Teams', 'deleteTeamsTeamIdReposOwnerRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const userDeleteUserEmailsBodyParam = [
      'string'
    ];
    describe('#deleteUserEmails - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteUserEmails(userDeleteUserEmailsBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'deleteUserEmails', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserFollowingUsername - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteUserFollowingUsername(userUsername, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'deleteUserFollowingUsername', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserKeysKeyId - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteUserKeysKeyId(userKeyId, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'deleteUserKeysKeyId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserStarredOwnerRepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteUserStarredOwnerRepo(userOwner, userRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'deleteUserStarredOwnerRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserSubscriptionsOwnerRepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteUserSubscriptionsOwnerRepo(userOwner, userRepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-GitHub-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('User', 'deleteUserSubscriptionsOwnerRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });
  });
});
